/*
** Module   : Connectable.java
** Abstract : An innterace for handles supporting the connect(), disconnect()
**            and connected() attributes..
**
** Copyright (c) 2013, Golden Code Development Corporation.
** ALL RIGHTS RESERVED. Use is subject to license terms.
**
**           Golden Code Development Corporation
**                      CONFIDENTIAL
**
** -#- -I- --Date-- -----------------------Description------------------------
** 001 CS  20130207 Created initial version.
*/

package com.goldencode.p2j.util;

/**
 * Provides access to the following handler methods
 * handler methods.
 * <table>
 * <tr>
 *    <th>attribute or method</th>
 *    <th>API</th>
 * </tr>
 * <tr>
 *    <td>CONNECT()</td>
 *    <td>{@link #connect(character)}, {@link #connect(String)}</td>
 * </tr>
 * <tr>
 *    <td>CONNECTED()</td>
 *    <td>{@link #connected()}</td>
 * </tr>
 * <tr>
 *    <td>DISCONNECT()</td>
 *    <td>{@link #disconnect()}</td>
 * </tr>
 * </table>
 */
public interface Connectable
{
   /**
    * Method declaration  for the CONNECT() procedure supported by sockets
    * web-services and server handles.
    *  
    * @param  options
    *         The set of parameters to establish the connect procedure.
    * 
    * @return <code>true</code> if connection succeeded, or <code>false</code>
    *         otherwise
    */
   public logical connect(character options);
   
   /**
    * Method declaration  for the CONNECT() procedure supported by sockets
    * web-services and server handles.
    *  
    * @param  options
    *         The set of parameters to establish the connect procedure.
    * 
    * @return <code>true</code> if connection succeeded, or <code>false</code>
    *         otherwise
    */
   public logical connect(String options);
   
   /**
    * Method declaration  for the CONNECTED() procedure supported by sockets
    * web-services and server handles, this will return <code>true</code> if
    * the socket is connected or <code>false</code> otherwise.
    * 
    * @return <code>true</code> if the socket is connected or <code>false</code> 
    *         otherwise.
    */
   public logical connected();
   
   /**
    * Method declaration  for the DISCONNECT() procedure supported by sockets
    * web-services and server handles, this will attempt to disconnect the 
    * resource and returns <code>true</code> if succeeded or <code>false</code> 
    * otherwise.
    * 
    * @return <code>true</code> if disconnect succeeded or <code>false</code> 
    *         otherwise.
    */
   public logical disconnect();
}
